# tr-lang-py
Python bindings for [tr-lang](https://github.com/kaiserthe13th/tr-lang)

## Installation
```console
$ pip install tr-lang-py
```

## Documentation
[tr-lang Documentation](https://tr-lang-docs.netlify.app/english)

## Contributing

To report bugs or suggest new features please use the [issue tracker](https://github.com/kaiserthe13th/tr-lang-py/issues)

Bugfix PR's are welcome!
